( cd usr/lib ; rm -rf libopencdk.so )
( cd usr/lib ; ln -sf libopencdk.so.10.0.6 libopencdk.so )
( cd usr/lib ; rm -rf libopencdk.so.10 )
( cd usr/lib ; ln -sf libopencdk.so.10.0.6 libopencdk.so.10 )
